Crate thin_status

Crate thin_status 

Structs

ErrorCodeIter
An iterator over the variants of ErrorCode
IsizeInPtr
Stores an isize as a tagged value inside a pointer. This means that one bit of isize isn’t available, and therefore only numbers within IsizeInPtr::MIN and IsizeIntPtr::MAX are convertible.
ThinArcOrInt
A type representing either a signed pointer-sized integer (isize) or a reference-counted pointer (ThinArc<H, T>).
ThinStatus
Holds a non-OK status code (in most cases ErrorCode), a descriptive string message, and optionally (if enabled by feature use_any) also [google_cloud_wkt::Any].
ThinStatusBuilder
Allows convenient construction of ThinStatus instances.
TryFromIsizeError
Returned when a value is out of the range of IsizeError.

Enums

ErrorCode
Derived from https://github.com/abseil/abseil-cpp/blob/master/absl/status/status.h. See the link for more information.