ThinStatus

Struct ThinStatus 

pub struct ThinStatus { /* private fields */ }
Holds a non-OK status code (in most cases ErrorCode), a descriptive string message, and optionally (if enabled by feature use_any) also [google_cloud_wkt::Any].

It occupies only a single pointer word, which either wraps a tagged integer code (if there is neither message nor details), or a ThinArc pointer that holds a more complex value. Furthermore its representation is never nullptr, therefore Option<ThinStatus> and Result<(), ThinStatus> occupy just a single memory word.

Note that Copy, Eq, PartialOrd and Hash are only provided (derived) when feature use_any is disabled, since the Any datatype doesn’t provide them.

Implementations

Source

impl ThinStatus

pub fn builder<'a, C: Into<NonZeroI32>>(code: C) -> ThinStatusBuilder<'a>

Constructs a builder that allows convenient creation of ThinStatus instances.

pub fn from_code<C: Into<NonZeroI32>>(code: C) -> Self

A utility function to create a status with just a raw code. If it fits, it’ll be stored just as a tagged integer inside an internal pointer.

pub fn code(&self) -> Option<ErrorCode>

Returns the stored error code, or None if the raw numerical value doesn’t match any of the ErrorCode values.

pub fn code_or_unknown(&self) -> ErrorCode

Convenience wrapper to code() that converts an unknown error to ErrorCode::Unknown.

pub fn code_raw(&self) -> NonZeroI32

Returns the raw numerical error code.

pub fn message(&self) -> &str

Returns the message attached to the status (if any).