ThinStatusBuilder

Struct ThinStatusBuilder 

pub struct ThinStatusBuilder<'a> { /* private fields */ }
Allows convenient construction of ThinStatus instances.

Implementations

Source

impl<'a> ThinStatusBuilder<'a>

pub fn new<C: Into<NonZeroI32>>(code: C) -> Self

Constructs a builder from an error code (which can be, and often is ErrorCode).

pub fn code<C: Into<NonZeroI32>>(self, code: C) -> Self

Sets the error code to code.

pub fn message<S: Into<Cow<'a, str>> + ?Sized>(self, message: S) -> Self

Sets the message to message, discarding any previous one. The builder captures only a reference to it to avoid copying.

pub fn build(self) -> ThinStatus